You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@avro.apache.org by "Thiruvalluvan M. G. (JIRA)" <ji...@apache.org> on 2010/01/13 08:06:54 UTC

[jira] Updated: (AVRO-315) Performance improvements to BinaryDecoder

     [ https://issues.apache.org/jira/browse/AVRO-315?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]

Thiruvalluvan M. G. updated AVRO-315:
-------------------------------------

    Attachment: AVRO-315.patch
                AVRO-315-test.patch

> Performance improvements to BinaryDecoder
> -----------------------------------------
>
>                 Key: AVRO-315
>                 URL: https://issues.apache.org/jira/browse/AVRO-315
>             Project: Avro
>          Issue Type: Improvement
>            Reporter: Thiruvalluvan M. G.
>         Attachments: AVRO-315-test.patch, AVRO-315.patch
>
>
> The forthcoming patch improves the performance of BinaryDecoder.readLong(), readFloat() and readDouble().
> The test-patch has a command-line program Perf in org.apache.avro.io in the (test part of the source directory) which tests the performance of readInt() (which calls readLong())  readFloat() and readDouble(). On my machine, the patch improves the performance by 10% for readInt() and about 50% for readFloat() and readDouble().
> The idea is to unroll the loops in readLong(), readFloat() and readDouble(). There is a small change in doReadBytes() which checks for most common condition before less common ones.

-- 
This message is automatically generated by JIRA.
-
You can reply to this email to add a comment to the issue online.